(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Lack is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Lack.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Printf
open Utils

let link base (target,file) =
  let cmd = sprintf "ln -s %s %s/_links/%s" file base target in
    ignore (command false cmd)

let clean base =
  let cmd = sprintf "rm -f %s/_links/*/*" base in
    ignore (command false cmd)

let expose base =
  let to_string var dir =
    sprintf "%s=%s/_links/%s:$%s\nexport %s" var base dir var var
  in
  let variables = [
    to_string "PATH" "bin";
    to_string "LD_LIBRARY_PATH" "lib";
    to_string "LIBRARY_PATH" "lib";
    to_string "C_INCLUDE_PATH" "include";
    to_string "CPLUS_INCLUDE_PATH" "include";
    to_string "MANPATH" "man";
    to_string "INFOPATH" "info";
    to_string "PYTHONPATH" "python";
    to_string "PKG_CONFIG_PATH" "pkgconfig";
  ]
  in
    List.iter print_endline variables;
    printf "LACK=%s\nexport LACK\n" base;
    ()

let update prefix =
  let packages = Find.find_meta prefix in
  let metas = List.map Meta.parse packages in
  let files = List.flatten (List.map Meta.env metas) in
    Sys.chdir prefix;
    clean prefix;
    List.iter (link prefix) files;
    true

let prepare base =
  let dir = !base^"/_links" in
    mkdir dir;
    List.iter (fun x -> mkdir (dir^"/"^x)) Meta.sources;
    ()

