(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Lack is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Lack.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Printf
open Filename

open Package
open Utils
open Install

let usage = sprintf "Lack %s, a package manager for all it lacks on your computer" Version.version

let _ =
  let verbose = ref false in
  let quiet = ref false in
  let xml = ref "" in
  let file = ref "" in
  let arguments = (Arg.align [
                     "--verbose", Arg.Set verbose    , " Display output of commands";
                     "--quiet"  , Arg.Set quiet      , " Don't display progression information";
                     "--file"   , Arg.Set_string file, " Don't download the sources, instead, use the file provided";
                   ])
  in
    Arg.parse arguments (fun x -> xml := x) usage;
    let quiet = not !verbose && !quiet in
      if !xml = "" then
        Arg.usage arguments usage
      else
        try
          let pkg = parse !verbose !xml base in
            if !file = "" then
              install quiet !verbose pkg !xml None
            else
              install quiet !verbose pkg !xml (Some !file)
        with
          | Package.File_not_found s -> printf "Unable to find the package file %s\n" s; exit 1
