(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Lack is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Lack.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Parse

exception InvalidMeta of string

type meta = {
  meta_name : string;
  meta_version : string;
  meta_source : string;
  meta_env : (string * string) list;
}

let parse meta_file =
  let x = Xml.parse_file meta_file in
    match x with
      | Xml.Element("meta", _, l) ->
          let name = find_value l "name" in
          let version = find_value l "version" in
          let source = find_value l "source" in
          let paths = Xml.children (find_node l "paths") in
            let g = function
              | Xml.Element("path", attrs, [Xml.PCData value]) ->
                  let name = List.assoc "name" attrs in
                    (name, value)
              | _ -> raise (InvalidMeta meta_file)
            in
            let env = List.map g paths in
              {
                meta_name = name;
                meta_version = version;
                meta_source = source;
                meta_env = env;
              }
      | _ -> raise (InvalidMeta meta_file)

let env meta = meta.meta_env

let sources = [
  "bin";
  "sbin";
  "lib";
  "include";
  "pkgconfig";
  "man/man1";
  "man/man2";
  "man/man3";
  "man/man4";
  "man/man5";
  "man/man6";
  "man/man7";
  "man/man8";
  "man/man9";
  "info";
  "python";
]

